@@ -1,4 +1,4 @@
-__version__ = "0.4"
+__version__ = "0.5"
 import logging
 import os
 import time
@@ -6,11 +6,8 @@ from email.utils import parsedate
 import requests
 
 
-def make_url(path, sandbox=True):
-    if sandbox:
-        BASE = "https://sandbox.liblynx.com"
-    else:
-        BASE = "https://connect.liblynx.com"
+def make_url(path):
+    BASE = os.environ.get("LIBLYNX_BASE") or "https://sandbox.liblynx.com"
     return "%s%s" % (BASE, path)
 
 
@@ -89,30 +86,35 @@ class Connect:
                 "api endpoint failed %s %s" % (r.status_code, r.text)
             )
 
-    def new_identification(self, ip, url, user_agent):
+    def api(self, msg, href, method="GET", data=None, successcode=200):
         headers = {
             "Authorization": "Bearer %s" % self.access_token,
             "Accept": "application/json",
             "Content-Type": "application/json",
         }
-        data = {"ip": ip, "url": url, "user_agent": user_agent}
-        r = requests.post(
+        if method == "GET":
+            r = requests.get(href, headers=headers,)
+        elif method == "POST":
+            r = requests.post(href, json=data, headers=headers,)
+        elif method == "DELETE":
+            r = requests.delete(href, headers=headers,)
+            return True
+        return if_success(r, msg, successcode)
+
+    def new_identification(self, ip, url, user_agent):
+        return self.api(
+            "new identification",
             self.endpoint["_links"]["@new_identification"]["href"],
-            json=data,
-            headers=headers,
+            "POST",
+            {"ip": ip, "url": url, "user_agent": user_agent},
+            201,
         )
-        return if_success(r, "new identification", successcode=201)
 
     def identification(self, anid):
-        headers = {
-            "Authorization": "Bearer %s" % self.access_token,
-            "Accept": "application/json",
-            "Content-Type": "application/json",
-        }
-        r = requests.get(
-            self.endpoint["_links"]["@get_identification"]["href"].replace(
-                "{id}", anid
-            ),
-            headers=headers,
+        href = self.endpoint["_links"]["@get_identification"]["href"].replace(
+            "{id}", anid
         )
-        return if_success(r, "get identification", successcode=200)
+        return self.api("get identification", href)
+
+
+# c.api("new account", c.endpoint["_links"]["@new_account"]["href"], "POST", {"account_name":"LCI Evaluation %s", "subscriptions":[{"title":"Foo", "start": "2020-11-01 10:56:58", "end": "2020-12-01 10:56:58"}]})
